#!/usr/local/bin/perl -w
#------------------------------------------------------------------------------
# Licensed Materials - Property of IBM (C) Copyright IBM Corp. 2010, 2010
# All Rights Reserved US Government Users Restricted Rights - Use, duplication
# or disclosure restricted by GSA ADP Schedule Contract with IBM Corp
#------------------------------------------------------------------------------

#  perl itcamyn.pl
#
#  Create SQL to rectify TEMS database objects after ITCAM upgrade
#
#  john alvord, IBM Corporation, 11 September 2015
#  jalvord@us.ibm.com
#
# tested on Windows Activestate 5.16.2
# Should work on Linux/Unix but not yet tested
#
# $DB::single=2;   # remember debug breakpoint
#     use re 'debug';
## todos

#use warnings::unused; # debug used to check for unused variables
use strict;
use warnings;

# See short history at end of module

my $gVersion = "0.51000";
my $gWin = (-e "C://") ? 1 : 0;    # 1=Windows, 0=Linux/Unix

use Data::Dumper;               # debug only

# a collection of variables which are used throughout the program.
# defined globally

my $args_start = join(" ",@ARGV);      # capture arguments for later processing
my $run_status = 0;                    # A count of pending runtime errors - used to allow multiple error detection before stopping process

# some common variables

my $rc;
my $ll;
my $oneline;

# forward declarations of subroutines

sub init;                                # read command line and ini file
sub logit;                               # queue one record to survey log
sub gettime;                             # get time
sub init_all;                            # input from txt files
sub parse_lst;                           # parse the KfwSQLClient output
sub get_timestamp;                       # current time in ITM Time Stamp format

# Situation related data

my $siti = -1;                             # count of situations
my @sit = ();                              # array of situations
my %sitx = ();                             # Index from situation name to index
my @sit_affinities = ();                   # array of affinities
my @sit_lstusrprf = ();                    # array of lstusrprf

my $lnodli = -1;
my @lnodl = ();
my %lnodlx = ();
my @lnodl_affinities = ();
my @lnodl_lstusrprf = ();

my $ccti = -1;
my @cct = ();
my %cctx = ();
my @cct_affinities = ();
my @cct_lstusrprf = ();

my $pcyi = -1;
my @pcy = ();
my %pcyx = ();
my @pcy_affinities = ();
my @pcy_lstusrprf = ();

# conversion affinities - Antonios Morello, WAS L3

# Current Affinity                            Table                 Replace with
# ------------------------------------------- ---------------------------     --------------
# &IBM.CAM7_WAS           0000000000#########     Garbage_Collection_Cycle        &IBM.CAM_WAS
# %IBM.IDMULTIPLE         0000000000#########     Garbage_Collection_Analysis     &IBM.CAM_WAS
# %IBM.IDMULTIPLE         000000000A#########     Application_Server              &IBM.CAM_WAS
# %IBM.STATIC185          0000000000#########     Garbage_Collection_Analysis     &IBM.CAM_WAS
# 00000000000000000000000000000010###########     Application_Server_Status       %IBM.STATIC186
# 00000000000000000000000000000010##000000000     Application_Server_Status       %IBM.STATIC186
# 0000G000000000000000000000000001#*000000000     Service_Components              &IBM.CAM_SCA
# 0000G000000000000000000000000021#*#########     Messaging_Engines               &IBM.CAM_ESB
# 0000G000000000000000000000000021#*000000000     Client_Communications           &IBM.CAM_ESB
# 0000m000000000000000000000000021#*000000000     Web_Services                    &IBM.CAM7_WAS
# 0000m000000000000000000000000021###########     Servlet_Sessions                &IBM.CAM7_WAS
# 0000m000000000000000000000000021##000000000     J2C_Connection_Pools            &IBM.CAM7_WAS
# 0000m000000000000000000000000021#0########F     DB_Connection_Pools             &IBM.CAM_WAS
# 0000m00000000000000000000000002100000000000     Request_Analysis                &IBM.CAM_WAS
# 0000m0000000000000000000000000I1#*000000000     High_Availability_Manager       &IBM.CAM_WAS
# 0000m0000000000000000000000000I1###########     Enterprise_Java_Beans           &IBM.CAM_WAS
# 0000m0000000000000000000000000I1##000000000     Application_Server              &IBM.CAM_WAS
# 0000m0000000000000000000000000I1#0########F     Application_Health_Status       &IBM.CAM_WAS
# 0000m0000000000000000000000000I1#y#########     Application_Health_Status       &IBM.CAM_WAS
# 0000m0000000000000000000000000I1#y000000000     Application_Health_Status       &IBM.CAM_WAS
# 0000m0000000000000000000000000I100000000000     Container_Transactions          &IBM.CAM_WAS
# 0000m0000000000000000000000000I1u0#########     Application_Server              &IBM.CAM_WAS
# 0000W000000000000000000000000000#*000000000     Portal_Summary                  %IBM.STATIC025
# 0000W00000000000000000000000000000000000000     Portal_Page_Summary             %IBM.STATIC025

# in most cases you can specify the first 32 characters of affinities
# If a full 43 character specification is required, specify it here.

my %affx = (
           # section for YN
           "&IBM.CAM7_WAS           00000000" => "&IBM.CAM_WAS",
           "%IBM.IDMULTIPLE         00000000" => "&IBM.CAM_WAS",
           "%IBM.STATIC185          00000000" => "&IBM.CAM_WAS",
           "00000000000000000000000000000010" => "%IBM.STATIC186",
           "0000G000000000000000000000000001" => "&IBM.CAM_SCA",
           "0000G000000000000000000000000021" => "&IBM.CAM_ESB",
           "0000m000000000000000000000000021" => "&IBM.CAM7_WAS",
           "0000m0000000000000000000000000I1" => "&IBM.CAM_WAS",
           "0000W000000000000000000000000000" => "%IBM.STATIC025",
           # section for YJ to be added later
           # section for HT to be added later
        );




# option and ini file variables variables

my $opt_txt;                    # input from .txt files
my $opt_txt_tsitdesc;           # TSITDESC txt file
my $opt_txt_tnodelst;           # TNODELST txt file
my $opt_txt_cct;                # CCT txt file
my $opt_txt_tpcydesc;           # TPCYDESC txt file
my $opt_lst;                    # input from .lst files
my $opt_lst_tsitdesc;           # TSITDESC lst file
my $opt_lst_tnodelst;           # TNODELST lst file
my $opt_lst_cct;                # CCT lst file
my $opt_lst_tpcydesc;           # TPCYDESC lst file
my $opt_log;                    # name of log file
my $opt_h;                      # help file
my $opt_o;                      # output file

# do basic initialization from parameters, ini file and standard input

$rc = init($args_start);

open FH, ">$opt_log" or die "can't open $opt_log: $!";

logit(0,"ITCAMYN000I - ICAM YN User Object Affinity Corrections $gVersion $args_start");

# process two different sources of situation data

$rc = init_all();

open OH, ">$opt_o" or die "can't open sql file $opt_o: $!";

my $sql_undo = $opt_o . ".undo";

open UH, ">$sql_undo" or die "can't open undo sql file $sql_undo: $!";

my $ctime = get_timestamp();
my $sqlline;
my $logline;
my $affkey;

# goal is to identify YN objects and update the Affinities

# UPDATE table_name
# SET column1=value1,column2=value2,...
# WHERE some_column=some_value;

for (my $s=0;$s<=$siti;$s++) {
   next if substr($sit[$s],0,12) eq "UADVISOR_KM5";   # this inexplicably matches one of the YN static affinities, so ignore it
   $affkey = $sit_affinities[$s];
   $affkey = substr($sit_affinities[$s],0,32) if !defined $affx{$affkey};
   next if !defined $affx{$affkey};
   $sqlline = "UPDATE O4SRV.TSITDESC ";
   $sqlline .= "SET AFFINITIES='$affx{$affkey}',LSTDATE='$ctime' ";
   $sqlline .= "WHERE SITNAME='$sit[$s]';";
   print OH "$sqlline\n";
   $sqlline = "UPDATE O4SRV.TSITDESC ";
   $sqlline .= "SET AFFINITIES='$sit_affinities[$s]',LSTDATE='$ctime' ";
   $sqlline .= "WHERE SITNAME='$sit[$s]';";
   print UH "$sqlline\n";
   $logline = "TSITDESC $sit[$s] Affinities old[$sit_affinities[$s]] new [$affx{$affkey}] last user[$sit_lstusrprf[$s]]";
   logit(0,"ITCAMYN001I - $logline");
}

for (my $s=0;$s<=$lnodli;$s++) {
   $affkey = $lnodl_affinities[$s];
   $affkey = substr($lnodl_affinities[$s],0,32) if !defined $affx{$affkey};
   next if !defined $affx{$affkey};
   $sqlline = "UPDATE O4SRV.TNODELST ";
   $sqlline .= "SET AFFINITIES='$affx{$affkey}',LSTDATE='$ctime' ";
   $sqlline .= "WHERE NODELIST='$lnodl[$s]' AND NODETYPE='M';";
   print OH "$sqlline\n";
   $sqlline = "UPDATE O4SRV.TNODELST ";
   $sqlline .= "SET AFFINITIES='$lnodl_affinities[$s]',LSTDATE='$ctime' ";
   $sqlline .= "WHERE NODELIST='$lnodl[$s]' AND NODETYPE='M';";
   print UH "$sqlline\n";
   $logline = "TNODELIST $lnodl[$s] Affinities old[$lnodl_affinities[$s]] new [$affx{$affkey}] last user[$lnodl_lstusrprf[$s]]";
   logit(0,"ITCAMYN001I - $logline");
}

for (my $s=0;$s<=$ccti;$s++) {
   $affkey = $cct_affinities[$s];
   $affkey = substr($cct_affinities[$s],0,32) if !defined  $affx{$affkey};
   next if !defined $affx{$affkey};
   $sqlline = "UPDATE O4SRV.CCT ";
   $sqlline .= "SET AFFINITIES='$affx{$affkey}',LSTDATE='$ctime' ";
   $sqlline .= "WHERE NAME='$cct[$s]';";
   print OH "$sqlline\n";
   $sqlline = "UPDATE O4SRV.CCT ";
   $sqlline .= "SET AFFINITIES='$cct_affinities[$s]',LSTDATE='$ctime' ";
   $sqlline .= "WHERE NAME='$cct[$s]';";
   print UH "$sqlline\n";
   $logline = "CCT $cct[$s] Affinities old[$cct_affinities[$s]] new [$affx{$affkey}] last user[$cct_lstusrprf[$s]]";
   logit(0,"ITCAMYN001I - $logline");
}

for (my $s=0;$s<=$pcyi;$s++) {
   $affkey = $pcy_affinities[$s];
   $affkey = substr($pcy_affinities[$s],0,32) if !defined  $affx{$affkey};
   next if !defined $affx{$affkey};
   $sqlline = "UPDATE O4SRV.TPCYDESC ";
   $sqlline .= "SET AFFINITIES='$affx{$affkey}',LSTDATE='$ctime' ";
   $sqlline .= "WHERE PCYNAME='$pcy[$s]';";
   print OH "$sqlline\n";
   $sqlline = "UPDATE O4SRV.TPCYDESC ";
   $sqlline .= "SET AFFINITIES='$pcy_affinities[$s]',LSTDATE='$ctime' ";
   $sqlline .= "WHERE PCYNAME='$pcy[$s]';";
   print UH "$sqlline\n";
   $logline = "TPCYDESC $pcy[$s] Affinities old[$pcy_affinities[$s]] new [$affx{$affkey}] last user[$pcy_lstusrprf[$s]]";
   logit(0,"ITCAMYN001I - $logline");
}
close OH;
close UH;

exit;

sub newpcy {
      my ($iaffinities,$ilstusrprf,$ipcyname) = @_;
      my $cx = $pcyx{$ipcyname};
      if (!defined $cx) {
         $pcyi += 1;
         $pcy[$pcyi] = $ipcyname;
         $pcyx{$ipcyname} = $pcyi;
         $pcy_affinities[$pcyi] = $iaffinities;
         $pcy_lstusrprf[$pcyi] = $ilstusrprf;
      }
}

sub newcct {
      my ($iaffinities,$ilstusrprf,$iname) = @_;
      my $cx = $cctx{$iname};
      if (!defined $cx) {
         $ccti += 1;
         $cct[$ccti] = $iname;
         $cctx{$iname} = $ccti;
         $cct_affinities[$ccti] = $iaffinities;
         $cct_lstusrprf[$ccti] = $ilstusrprf;
      }
}

sub newlst {
      my ($iaffinities,$ilstusrprf,$inodelist) = @_;
      my $lx = $lnodlx{$inodelist};
      if (!defined $lx) {
         $lnodli += 1;
         $lnodl[$lnodli] = $inodelist;
         $lnodlx{$inodelist} = $lnodli;
         $lnodl_affinities[$lnodli] = $iaffinities;
         $lnodl_lstusrprf[$lnodli] = $ilstusrprf;
      }
}

sub newsit {
      my ($iaffinities,$ilstusrprf,$isitname) = @_;
      $siti += 1;
      $sit[$siti] = $isitname;
      $sitx{$isitname} = $siti;
      $sit_affinities[$siti] = $iaffinities;
      $sit_lstusrprf[$siti] = $ilstusrprf;
}

# There may be a better way to do this, but this was clear and worked.
# The input $lcount must be matched up to the number of columns
# SELECTED in the SQL.
# [1]  OGRP_59B815CE8A3F4403  OGRP_6F783DF5FF904988  2010  2010
sub parse_lst {
#$DB::single=2;
  my ($lcount,$inline,$cref) = @_;            # count of desired chunks and the input line
  my @retlist = ();                     # an array of strings to return
  my $chunk = "";                       # One chunk
  my $oct = 1;                          # output chunk count
  my $rest;                             # the rest of the line to process
  my $fixed;
#  chop($inline);
  $inline =~ /\]\s*(.*)/;               # skip by [NNN]  field
  $rest = " " . $1 . "        ";
  my $lenrest = length($rest);          # length of $rest string
  my $restpos = 0;                      # postion studied in the $rest string
  my $nextpos = 0;                      # floating next position in $rest string

  # at each stage we can identify a field with values
  #         <blank>data<blank>
  # and a blank field
  #         <blank><blank>
  # We allow a single embedded blank as part of the field
  #         data<blank>data
  # for the last field, we allow imbedded blanks and logic not needed
  while ($restpos < $lenrest) {
#$DB::single=2;
     $fixed = $cref->{$oct};
#$DB::single=2;
     if (defined $fixed) {
#$DB::single=2;
        $chunk = substr($rest,$restpos+1,$fixed);
        push @retlist, $chunk;                 # record null data chunk
        $restpos += 2 + $fixed;
        $chunk = "";
        $oct += 1;
#$DB::single=2;
#my $x = 1;
        next;
     }
     if ($oct < $lcount) {
        if (substr($rest,$restpos,2) eq "  ") {               # null string case
           $chunk = "";
           push @retlist, $chunk;                 # record null data chunk
           $restpos += 2;
        } else {
           $nextpos = index($rest," ",$restpos+1);
           if (substr($rest,$nextpos,2) eq "  ") {
              $chunk .= substr($rest,$restpos+1,$nextpos-$restpos-1);
              push @retlist, $chunk;                 # record null data chunk
              $chunk = "";
              $oct += 1;
              $restpos = $nextpos + 1;
           } else {
              $chunk .= substr($rest,$restpos+1,$nextpos-$restpos);
              $restpos = $nextpos;
           }
        }
     } else {
        $chunk = substr($rest,$restpos+1);
        $chunk =~ s/\s+$//;                    # strip trailing blanks
        push @retlist, $chunk;                 # record last data chunk
        last;
     }
  }
  return @retlist;
}


# following routine gets data from txt files. tems2sql.pl is an internal only program which can
# extract data from a TEMS database file. The way it is used here the results are a fixed column
# orientation.

sub init_all {
   my @ksit_data;
   my $iaffinities;
   my $ilstusrprf;
   my $isitname;
   my $irest;

   my @knod_data;
   my $inodelist;
   my $inodetype;

   my @kcct_data;
   my $iname;

   my @kpcy_data;
   my $ipcyname;

   my $read_fn;

   # (1) the TSITDESC data
   $read_fn = $opt_txt_tsitdesc if $opt_txt == 1;
   $read_fn = $opt_lst_tsitdesc if $opt_lst == 1;

   open(KSIT, "< $read_fn") || die("Could not open TSITDESC $read_fn\n");
   @ksit_data = <KSIT>;
   close(KSIT);

   $ll = 0;
   foreach $oneline (@ksit_data) {
      $ll += 1;
      chop $oneline;
      $oneline .= " " x 1000;
      if ($opt_txt == 1) {
         next if $ll < 5;
         $iaffinities = substr($oneline,0,43);
         $iaffinities =~ s/\s+$//;   #trim trailing whitespace
         $ilstusrprf = substr($oneline,45,10);
         $ilstusrprf =~ s/\s+$//;   #trim trailing whitespace
         $isitname = substr($oneline,56,32);
         $isitname =~ s/\s+$//;   #trim trailing whitespace
      } else {
         #%CANDLE_HOME%\cnps\KfwSQLClient /e "SELECT ID,GRPCLASS FROM O4SRV.TGROUP" >QA1DGRPA.DB.LST
         #%CANDLE_HOME%\cnps\KfwSQLClient /e "SELECT AFFINITIES,LSTUSRPRF,SITNAME FROM O4SRV.TSITDESC" >QA1CSITF.DB.LST
         next if substr($oneline,0,1) ne "[";      # exclude non-data lines
         my %cref = (1=>43,);
        ($iaffinities,$ilstusrprf,$isitname,$irest) = parse_lst(4,$oneline,\%cref);
      }
      newsit($iaffinities,$ilstusrprf,$isitname);
   }

   # (2) the TNODELST data

   $read_fn = $opt_txt_tnodelst if $opt_txt == 1;
   $read_fn = $opt_lst_tnodelst if $opt_lst == 1;

   open(KNOD, "< $read_fn") || die("Could not open TNODELST $read_fn\n");
   @knod_data = <KNOD>;
   close(KNOD);

   $ll = 0;
   foreach $oneline (@knod_data) {
      $ll += 1;
      chop $oneline;
      $oneline .= " " x 1000;
      if ($opt_txt == 1) {
         next if $ll < 5;
         $iaffinities = substr($oneline,0,43);
         $iaffinities =~ s/\s+$//;   #trim trailing whitespace
         $ilstusrprf = substr($oneline,45,10);
         $ilstusrprf =~ s/\s+$//;   #trim trailing whitespace
         $inodelist = substr($oneline,56,32);
         $inodelist =~ s/\s+$//;   #trim trailing whitespace
      } else {
         #%CANDLE_HOME%\cnps\KfwSQLClient /e "SELECT ID,GRPCLASS FROM O4SRV.TGROUP" >QA1DGRPA.DB.LST
         #%CANDLE_HOME%\cnps\KfwSQLClient /e "SELECT AFFINITIES,LSTUSRPRF,NODELIST,NODETYPE FROM O4SRV.TNODELST" >QA1CNODL.DB.LST
         next if substr($oneline,0,1) ne "[";      # exclude non-data lines
         my %cref = (1=>43,);
         ($iaffinities,$ilstusrprf,$inodelist,$inodetype) = parse_lst(4,$oneline,\%cref);
         next if $inodetype eq "V";
         next if substr($inodelist,0,1) eq "*";
      }
      newlst($iaffinities,$ilstusrprf,$inodelist);
   }

   # (3) the CCT data

   $read_fn = $opt_txt_cct if $opt_txt == 1;
   $read_fn = $opt_lst_cct if $opt_lst == 1;

   open(KCCT, "< $read_fn") || die("Could not open CCT $read_fn\n");
   @kcct_data = <KCCT>;
   close(KCCT);

   $ll = 0;
   foreach $oneline (@kcct_data) {
      $ll += 1;
      chop $oneline;
      $oneline .= " " x 1000;
      if ($opt_txt == 1) {
         next if $ll < 5;
         $iaffinities = substr($oneline,0,43);
         $iaffinities =~ s/\s+$//;   #trim trailing whitespace
         $ilstusrprf = substr($oneline,45,10);
         $ilstusrprf =~ s/\s+$//;   #trim trailing whitespace
         $iname = substr($oneline,56,128);
         $iname =~ s/\s+$//;   #trim trailing whitespace
      } else {
         #%CANDLE_HOME%\cnps\KfwSQLClient /e "SELECT AFFINITIES,LSTUSRPRF,NAME FROM O4SRV.CCT" >QA1CSITF.DB.LST
         next if substr($oneline,0,1) ne "[";      # exclude non-data lines
         my %cref = (1=>43,);
         ($iaffinities,$ilstusrprf,$iname) = parse_lst(3,$oneline,\%cref);
      }
      newcct($iaffinities,$ilstusrprf,$iname);
   }

   # (4) the TPCYDESC data

   $read_fn = $opt_txt_tpcydesc if $opt_txt == 1;
   $read_fn = $opt_lst_tpcydesc if $opt_lst == 1;

   open(KPCY, "< $read_fn") || die("Could not open TPCYDESC $read_fn\n");
   @kpcy_data = <KPCY>;
   close(KPCY);

   $ll = 0;
   foreach $oneline (@kpcy_data) {
      $ll += 1;
      chop $oneline;
      $oneline .= " " x 1000;
      if ($opt_txt == 1) {
         next if $ll < 5;
         $iaffinities = substr($oneline,0,43);
         $iaffinities =~ s/\s+$//;   #trim trailing whitespace
         $ilstusrprf = substr($oneline,45,10);
         $ilstusrprf =~ s/\s+$//;   #trim trailing whitespace
         $ipcyname = substr($oneline,56,32);
         $ipcyname =~ s/\s+$//;   #trim trailing whitespace
      } else {
         #%CANDLE_HOME%\cnps\KfwSQLClient /e "SELECT AFFINITIES,LSTUSRPRF,PCYNAME FROM O4SRV.TPCYDESC" >QA1DPCFY.DB.LST
         next if substr($oneline,0,1) ne "[";      # exclude non-data lines
         my %cref = (1=>43,);
         ($iaffinities,$ilstusrprf,$ipcyname) = parse_lst(3,$oneline,\%cref);
      }
      newpcy($iaffinities,$ilstusrprf,$ipcyname);
   }
}


# Get options from command line - first priority
sub init {
   while (@ARGV) {
      if ($ARGV[0] eq "-h") {
         &GiveHelp;                        # print help and exit
      }
      if ($ARGV[0] eq "-txt") {
         $opt_txt = 1;
         shift(@ARGV);
      } elsif ($ARGV[0] eq "-lst") {
         $opt_lst = 1;
         shift(@ARGV);
      } elsif ($ARGV[0] eq "-o") {
         shift(@ARGV);
         $opt_o = shift(@ARGV);
         die "-o specified but no file found\n" if !defined $opt_o;
      } else {
         $opt_log = shift(@ARGV);
         die "log file not defined\n" if !defined $opt_log;
      }
   }

   # Following are command line only defaults. All others can be set from the ini file

   if (defined $opt_txt) {
      $opt_txt_tsitdesc = "QA1CSITF.DB.TXT";
      $opt_txt_cct      = "QA1DCCT.DB.TXT";
      $opt_txt_tpcydesc = "QA1DPCYF.DB.TXT";
      $opt_txt_tnodelst  = "QA1CNODL.DB.TXT";
   } elsif (defined $opt_lst) {
      $opt_lst_tsitdesc = "QA1CSITF.DB.LST";
      $opt_lst_cct      = "QA1DCCT.DB.LST";
      $opt_lst_tpcydesc = "QA1DPCYF.DB.LST";
      $opt_lst_tnodelst  = "QA1CNODL.DB.LST";
   }


   # defaults for options not set otherwise

   if (!defined $opt_log) {$opt_log = "itcamyn.log";}           # default log file if not specified
   if (!defined $opt_h) {$opt_h=0;}                            # help flag
   if (!defined $opt_o) {$opt_o="itcamyn.sql";}       # default output file
   if (!defined $opt_txt) {$opt_txt = 0;}                      # default no txt input
   if (!defined $opt_lst) {$opt_lst = 0;}                      # default no lst input

   # complain about options which must be present
   if (($opt_txt + $opt_lst) != 1) {
      print STDERR "SITINFO006E exactly one of txt/lst must be present\n";
      $run_status++;
   }

   # if any errors, then dump log and exit
   # this way we can show multiple errors at startup
   if ($run_status) { exit 1;}

}



#------------------------------------------------------------------------------
sub GiveHelp
{
  $0 =~ s|(.*)/([^/]*)|$2|;
  print <<"EndOFHelp";

  $0 v$gVersion

  This script creates ITCAM YN transition UPDATE SQL file

  Default values:
    log           : itcamyn.log
    h             : 0  display help information
    lst           : get data from KfwSQLClient SQL data
    txt           : get data from TEMS2SQL data

  Example invovation
    $0  -lst

EndOFHelp
exit;
}


#------------------------------------------------------------------------------
# capture log record
sub logit
{
   my $level = shift;
   my $iline = shift;
   my $itime = gettime();
   chop($itime);
   my $oline = $itime . " " . $level . " " . $iline;
   print FH "$oline\n";
}

#------------------------------------------------------------------------------
# capture agent log record
#------------------------------------------------------------------------------
# capture agent error record

# write output log
# return timestamp
sub gettime
{
   my $sec;
   my $min;
   my $hour;
   my $mday;
   my $mon;
   my $year;
   my $wday;
   my $yday;
   my $isdst;
   ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time);
   return sprintf "%4d-%02d-%02d %02d:%02d:%02d\n",$year+1900,$mon+1,$mday,$hour,$min,$sec;
}

# get current time in ITM standard timestamp form
sub get_timestamp {
   my $sec;
   my $min;
   my $hour;
   my $mday;
   my $mon;
   my $year;
   my $wday;
   my $yday;
   my $isdst;

   ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time);
   $year += 1900;
   $mon += 1;


   my $nyy = substr("00" . $year,-2,2);
   my $nmo = substr("00" . $mon,-2,2);
   my $ndd = substr("00" . $mday,-2,2);
   my $nhh = substr("00" . $hour,-2,2);
   my $nmm = substr("00" . $min,-2,2);
   my $nss = substr("00" . $sec,-2,2);

   my $etime = "1" . $nyy . $nmo . $ndd . $nhh . $nmm . $nss . "000";  # check time in ITM 16 byte format
   return $etime;
}

# History log

# 0.50000  : New script based on sitinfo.pl
# 0.51000  : Add itcanyn.sql.undo file to reverse changes if desired
